# Telium


# For development
1. Create virtual environment `python3 -m venv venv`
2. Activate virtual environment `source venv/bin/activate`
3. Install requirements `pip install -r requirements.txt`
4. Add pre-commit hooks `pre-commit install`
